@@ -241,9 +241,17 @@ def _fetch_allevents_event_json(
             return
         return True
 
+    # match datasets
     matched = list(filter(_match, allevents.items()))
     names = set(x[1]["commonName"] for x in matched)
-    if matched and len(names) == 1:
+
+    # one dataset has an exact name match, so discard everything else
+    if event in names:
+        matched = [x for x in matched if x[1]["commonName"] == event]
+        names = set(x[1]["commonName"] for x in matched)
+
+    # we have a winner!
+    if len(names) == 1:
         key, meta = sorted(matched, key=lambda x: x[1]["version"])[-1]
         return {"events": {key: meta}}
 
