@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """Tests for :mod:`gwosc.datasets`
 """
@@ -75,7 +61,9 @@ def test_find_datasets_detector():
 def test_find_datasets_type():
     runsets = datasets.find_datasets(type='run')
     assert 'O1' in runsets
-    run_regex = re.compile(r'\A([OS]\d+|BKGW\d{6})(_\d+KHZ)?(_[RV]\d+)?\Z')
+    run_regex = re.compile(
+        r'\A([OS]\d+([a-z])?|BKGW\d{6})(_\d+KHZ)?(_[RV]\d+)?\Z',
+    )
     for dset in runsets:
         assert run_regex.match(dset)
 
@@ -102,12 +90,15 @@ def test_find_datasets_event_version_detector():
     assert "GW150914-v3" not in sets  # v3
 
 
+@mock.patch("gwosc.datasets._run_datasets", return_value=[])
+def test_find_datasets_warning(_):
+    with pytest.warns(None):
+        datasets.find_datasets(type='run', version=1)
+
+
 @pytest.mark.remote
 def test_event_gps():
     assert datasets.event_gps('GW170817') == 1187008882.4
-    with pytest.raises(ValueError) as exc:
-        datasets.event_gps('GW123456')
-    assert str(exc.value) == 'no event dataset found for \'GW123456\''
 
 
 @mock.patch(
@@ -119,10 +110,6 @@ def test_event_gps():
 )
 def test_event_gps_local(fetch):
     assert datasets.event_gps('GW150914') == 12345
-    fetch.side_effect = ValueError('test')
-    with pytest.raises(ValueError) as exc:
-        datasets.event_gps('something')
-    assert str(exc.value) == "no event dataset found for 'something'"
 
 
 @pytest.mark.remote
