@@ -1,20 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Cardiff University, 2018-2020
-#
-# This file is part of GWOSC.
-#
-# GWOSC is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GWOSC is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GWOSC.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (C) Cardiff University (2018-2021)
+# SPDX-License-Identifier: MIT
 
 """Tests for :mod:`gwosc.urls`
 """
@@ -80,7 +66,7 @@ def test_match_local(mock_urls):
 def test_match_local_tag_error(mock_urls):
     with pytest.raises(ValueError) as exc:
         gwosc_urls.match(mock_urls)
-    assert str(exc.value).startswith('multiple LOSC URL tags')
+    assert str(exc.value).startswith('multiple GWOSC URL tags')
 
 
 def test_match_empty():
